#Chapter 7 R script

#reading in data and assigning variable names
bprs <- read.table("bprs.dat", header=FALSE)

names <- c(paste("item", 1:9, sep = "0"),
           paste("item", 10:18, sep = ""))
names(bprs) <- names

#looking at first 20 rows of data for first 8 items
bprs[1:20,1:8]

#examining symptom endorsement rates for 16 items to be used
colMeans(bprs[1:16])


#loading lavaan
library(lavaan)


#testing hypothesized factor structure
cat.1 <- '#measurement model
          Thought =~ item08 + item11 + item12 + item15
          Anergia =~ item03 + item13 + item14 + item16
          Affect =~ item01 + item02 + item05 + item09 + item10
          Disorg =~ item04 + item06 + item07
         '
fit.1 <- cfa(cat.1, data=bprs, std.lv=TRUE, ordered=names[1:16])
summary(fit.1, fit.measures=TRUE, estimates=FALSE)
modindices(fit.1, sort.=TRUE, minimum.value=10)


#removing item 13
cat.2 <- '#measurement model
          Thought =~ item08 + item11 + item12 + item15
          Anergia =~ item03 + item14 + item16
          Affect =~ item01 + item02 + item05 + item09 + item10
          Disorg =~ item04 + item06 + item07
         '
fit.2 <- cfa(cat.2, data=bprs, std.lv=TRUE, ordered=names[1:16])
summary(fit.2, fit.measures=TRUE, rsquare=TRUE)
modindices(fit.2, sort.=TRUE, minimum.value=10)


#extracting threshold and loading estimates to compute item characteristic curves
est <- parameterEstimates(fit.2)
threshold <- est[est$op=="|",c("lhs","est")]
loading <- est[est$op=="=~",c("rhs","est")]
names(threshold) <- c("item","est")
names(loading) <- c("item","est")


#plotting ICCs for Thought Disorder (rows 1-4)

plot(c(-4,4),c(0,1),type="n",xlab="Eta",ylab="Endorsement Probability")
items <- c("item08","item11","item12","item15")
lines <- c(1:length(items))
colors <- rainbow(length(items))

for (i in 1:4){
  eta <- seq(-4, 4, by=.1) 
  int <- -1*threshold[i,"est"]
  slp <- loading[i,"est"]
  prob <- pnorm(int + slp*eta)
  dat <- data.frame(cbind(eta, prob))

  lines(dat$eta, dat$prob, type="l", lwd=2, lty=lines[i], 
        col=colors[i])
}

title("Item Characteristic Curves: Thought Disorder")
legend(-4, 1, items, col=colors, lty=lines, lwd=2)


#plotting ICCs for Anergia (rows 5-7)

plot(c(-4,4),c(0,1),type="n",xlab="Eta",ylab="Endorsement Probability")
items <- c("item03", "item14", "item16")
lines <- c(1:length(items))
colors <- rainbow(length(items))

for (i in 5:7){
  eta <- seq(-4, 4, by=.1) 
  int <- -1*threshold[i,"est"]
  slp <- loading[i,"est"]
  prob <- pnorm(int + slp*eta)
  dat <- data.frame(cbind(eta, prob))
  
  lines(dat$eta, dat$prob, type="l", lwd=2, lty=lines[i-4], 
        col=colors[i-4])
}

title("Item Characteristic Curves: Anergia")
legend(-4, 1, items, col=colors, lty=lines, lwd=2)


#plotting ICCs for Affect (rows 8-12)

plot(c(-4,4),c(0,1),type="n",xlab="Eta",ylab="Endorsement Probability")
items <- c("item01", "item02", "item05", "item09", "item10")
lines <- c(1:length(items))
colors <- rainbow(length(items))

for (i in 8:12){
  eta <- seq(-4, 4, by=.1) 
  int <- -1*threshold[i,"est"]
  slp <- loading[i,"est"]
  prob <- pnorm(int + slp*eta)
  dat <- data.frame(cbind(eta, prob))
  
  lines(dat$eta, dat$prob, type="l", lwd=2, lty=lines[i-7], 
        col=colors[i-7])
}

title("Item Characteristic Curves: Affect")
legend(-4, 1, items, col=colors, lty=lines, lwd=2)


#plotting ICCs for Disorganization (rows 13-15)

plot(c(-4,4),c(0,1),type="n",xlab="Eta",ylab="Endorsement Probability")
items <- c("item04","item06","item07")
lines <- c(1:length(items))
colors <- rainbow(length(items))

for (i in 13:15){
  eta <- seq(-4, 4, by=.1) 
  int <- -1*threshold[i,"est"]
  slp <- loading[i,"est"]
  prob <- pnorm(int + slp*eta)
  dat <- data.frame(cbind(eta, prob))
  
  lines(dat$eta, dat$prob, type="l", lwd=2, lty=lines[i-12], 
        col=colors[i-12])
}

title("Item Characteristic Curves: Disorganization")
legend(-4, 1, items, col=colors, lty=lines, lwd=2)

