#Chapter 8 R script

#reading in data, assigning variable names
classes <- rep("numeric",12)
anti <- read.table("anti.dat", header=FALSE, colClasses=classes, na.strings=".")
y <- paste("anti", 6:14, sep = "")
names(anti) <- c(c("id","gen","homecog"),y)

#descriptive statistics
library(psych)
describe(anti[c("gen","homecog",y)])

#loading lavaan
library(lavaan)

#fitting intercept only LCM
int <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
             1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
             1*anti14 
       '
fit.int <- growth(int, data=anti, missing="ML")
summary(fit.int, fit.measures=TRUE, estimates=FALSE)

coverage <- lavInspect(fit.int, what = "coverage")
coverage*405

#fitting linear LCM
lin <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
             1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
             1*anti14 
        S =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
             4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
             8*anti14 
         '
fit.lin <- growth(lin, data=anti, missing="ML")
summary(fit.lin, fit.measures=TRUE, rsquare=TRUE)

lavTestLRT(fit.lin, fit.int)


#fitting quadratic LCM
quad <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
              1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
              1*anti14 
         L =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
              4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
              8*anti14 
         Q =~ 0*anti6 + 1*anti7 + 4*anti8 + 9*anti9 +
              16*anti10 + 25*anti11 + 36*anti12 + 49*anti13 +
              64*anti14 
        '
fit.quad <- growth(quad, data=anti, missing="ML")
summary(fit.quad, fit.measures=TRUE, rsquare=TRUE)

lavTestLRT(fit.quad, fit.lin)


#freed loading LCM
free.1 <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
                1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
                1*anti14 
           S =~ 0*anti6 + 1*anti7 + anti8 + anti9 +
                anti10 + anti11 + anti12 + anti13 +
                anti14 
          '
fit.free.1 <- growth(free.1, data=anti, missing="ML")
summary(fit.free.1, fit.measures=TRUE, rsquare=TRUE)

lavTestLRT(fit.free.1, fit.lin)

free.2 <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
                1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
                1*anti14 
           S =~ 0*anti6 + anti7 + anti8 + anti9 +
                anti10 + anti11 + anti12 + anti13 +
                1*anti14 
          '
fit.free.2 <- growth(free.2, data=anti, missing="ML")
summary(fit.free.2)


#conditional linear LCM with gender
gen <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
             1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
             1*anti14 
        S =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
             4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
             8*anti14 
        I ~ gen
        S ~ gen
       '
fit.gen <- growth(gen, data=anti, missing="ML")
summary(fit.gen, fit.measures=TRUE, rsquare=TRUE)


#simple slopes analysis with gender
gen <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
             1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
             1*anti14 
        S =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
             4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
             8*anti14 
        I ~ a1*1 + g11*gen
        S ~ a2*1 + g21*gen

        #simple intercept and slope for girls
        int_girl := a1
        slp_girl := a2

        #simple intercept and slope for boys
        int_boy := a1 + g11
        slp_boy := a2 + g21
       '
fit.gen <- growth(gen, data=anti, missing="ML")
summary(fit.gen)

plot(c(6,14),c(0,3),type="n",xlab="Age",ylab="Antisocial Behavior")

age <- seq(6, 14, by=1)
pred.girl <- 1.224 + .066*(age-6)
pred.boy <- 2.013 + .080*(age-6)
dat <- data.frame(cbind(age,pred.girl,pred.boy))

lines(dat$age, dat$pred.girl, type="l", lwd=2, lty=1)
lines(dat$age, dat$pred.boy, type="l", lwd=2, lty=2)

title("Simple Trajectories Conditional on Sex")
legend(12, .5, c("girl","boy"), lty=c(1,2), lwd=2)


#conditional linear LCM with homecog
home <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
              1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
              1*anti14 
         S =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
              4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
              8*anti14 
         I ~ homecog
         S ~ homecog
        '
fit.home <- growth(home, data=anti, missing="ML")
summary(fit.home, fit.measures=TRUE, rsquare=TRUE)


#simple slopes analysis with homecog
home <- 'I =~ 1*anti6 + 1*anti7 + 1*anti8 + 1*anti9 +
              1*anti10 + 1*anti11 + 1*anti12 + 1*anti13 +
              1*anti14 
         S =~ 0*anti6 + 1*anti7 + 2*anti8 + 3*anti9 +
              4*anti10 + 5*anti11 + 6*anti12 + 7*anti13 +
              8*anti14 
         I ~ a1*1 + g11*homecog
         S ~ a2*1 + g21*homecog

         #simple intercept and slope for low homecog
         int_lo := a1 - 2.58*g11
         slp_lo := a2 - 2.58*g21

         #simple intercept and slope for medium homecog
         int_md := a1 
         slp_md := a2 

         #simple intercept and slope for high homecog
         int_hi := a1 + 2.58*g11
         slp_hi := a2 + 2.58*g21
        '
fit.home <- growth(home, data=anti, missing="ML")
summary(fit.home)

plot(c(6,14),c(0,3),type="n",xlab="Age",ylab="Antisocial Behavior")

age <- seq(6, 14, by=1)
pred.lo <- 1.823 + .114*(age-6)
pred.md <- 1.622 + .075*(age-6)
pred.hi <- 1.421 + .035*(age-6)
dat <- data.frame(cbind(age,pred.lo,pred.md,pred.hi))

lines(dat$age, dat$pred.lo, type="l", lwd=2, lty=2)
lines(dat$age, dat$pred.md, type="l", lwd=2, lty=1)
lines(dat$age, dat$pred.hi, type="l", lwd=2, lty=3)

title("Simple Trajectories Conditional on Cognitive Support in the Home")
legend(12, .75, c("low","medium", "high"), title="Cognitive Support", lty=c(2,1,3), lwd=2)
